% MalariaSim
% Advanced model to simulate dynamics in malaria epidemy
% ---------------------------------------
% ----- Unknowns
% S_h(t)  Number of susceptible humans at time t.
% Eh(t)   Number of humans exposed to malaria infection at time t.
% Ih(t)   Number of infected humans at time t.
% Rh (t)  Number of recovered humans at time t.
% Sm (t)  Number of susceptible mosquitoes at time t.
% Em (t)  Number of exposed mosquitoes at time t.
% Im (t)  Number of infectious mosquitoes at time t.
% ----- parameters 
% Lambda_h  Birth number of humans.
% Lambda_m  Birth number of mosquitoes.
% b         Biting rate of the mosquito.
% beta_h    Probability that a bite by an infectious mosquito results 
%           in transmission of disease to human.
% beta_m    Probability that a bite results in transmission of parasite 
%           to a susceptible mosquito.
% mu_h      Per capita rate of human mortality.
% mu_m      Per capita rate of mosquito mortality.
% delta_h   Disease induced death rate of human.
% delta_m   Disease induced death rate of mosquito.
% alfa_h    Per capital rate of progression of humans from the exposed
%           state to the infectious state.
% alfa_m    Per capital rate of progression of mosquitoes from the exposed
%           state to the infectious state.
% r         Recovery rate of humans.
% omega     Per capital rate of loss of immunity in humans.
% nu_h      Proportion of an antibody produced by human in response 
%           to the incidence of infection caused by mosquito.
% nu_m      Proportion of an antibody produced by mosquito in response 
%           to the incidence of infection caused by human.


% Set start- and end-time of the simulation
starttid = 0;
sluttid = 100;
tidsintervall = [starttid sluttid];

% set parameters parametrarna

Lambda_h = 20;
Lambda_m = 40;
b        = 0.075; 
beta_h   = 0.3;    
beta_m   = 0.5;       
mu_h     = 0.015;
mu_m     = 0.02;
delta_h  = 0.05;
delta_m  = 0.15; 
alfa_h   = 0.6;      
alfa_m   = 0.6;
r        = 0.05;
omega    = 0.02;
nu_h     = 0.5;       
nu_m     = 0.5;

% ----- Initial values of the variables at time 0
S_h0 = 900;
S_m0 = 900;
E_h0 = 30;
E_m0 = 330;
I_h0 = 50;
I_m0 = 270;
R_h0 = 20;

y0 = [...]; % initial vector
param = [...]; % parameters

%S----- Set the parameters for the Matlab solver
%val = odeset('OutputFcn','odeplot','RelTol', 1e-1);
val = odeset;
% Choose an ODE solver
[t_ode, y_ode] = ode45(@(t,y) MalariaODE(t,y,param), tidsintervall, y0, val);
%----- plot the ODE solution 

figure(1),clf
plot(t_ode,y_ode(:,1),'b--','LineWidth',2),hold
plot(t_ode,y_ode(:,2),'b.','LineWidth',2)
plot(t_ode,y_ode(:,3),'m--','LineWidth',2)
plot(t_ode,y_ode(:,4),'m.','LineWidth',2)
plot(t_ode,y_ode(:,5),'r--','LineWidth',2)
plot(t_ode,y_ode(:,6),'r.','LineWidth',2)
plot(t_ode,y_ode(:,7),'Color',[.61 .51 .74],'LineWidth',2)
xlabel('time')
title('Simulation of malaria epidemy (ODE)');
legend(...);

step = ...;
[t, y] = SSA(@Malaria_prop, @Malaria_stoch, y0, tidsintervall, param, step);
%----- plot the SSA solution 
figure(2),clf
plot(t,y(:,1),'b--'),hold
plot(t,y(:,2),'b.')
plot(t,y(:,3),'m--')
plot(t,y(:,4),'m.')
plot(t,y(:,5),'r--')
plot(t,y(:,6),'r.')
plot(t,y(:,7),'Color',[.61 .51 .74])

 xlabel('time')
 title('Simulation of malaria epidemy (SSA)');
 legend(...);

 
Sum_h = y_ode(:,1)+y_ode(:,3)+y_ode(:,5)+y_ode(:,7);
Sum_m = y_ode(:,2)+y_ode(:,4)+y_ode(:,6);
Sum_hmc = y(:,1)+y(:,3)+y(:,5)+y(:,7);
Sum_mmc = y(:,2)+y(:,4)+y(:,6);
figure(3),clf,plot(t_ode,Sum_h,'b','LineWidth',2),hold,plot(t_ode,Sum_m,'m','LineWidth',2)
plot(t,Sum_hmc,'b.'),plot(t,Sum_mmc,'m.')
legend('ODE_h','ODE_m','SSA_h','SSA_m')

return
